@@ -98,9 +98,9 @@ kml_layer.SpatialPixels <- function(
     z.lim <- eval(call.lst[["z.lim"]]) 
     r <- calc(r, fun=function(x){ x[x < z.lim[1]] <- z.lim[1]; return(x)}) 
     r <- calc(r, fun=function(x){ x[x > z.lim[2]] <- z.lim[2]; return(x)})
-    raster::image(r, col = colour_scale, zlim = z.lim, frame.plot = FALSE, main="")
+    raster::image(r, col = colour_scale, zlim = z.lim, frame.plot = FALSE, main="", maxpixels=ncell(r))
   } else {
-    raster::image(r, col = colour_scale, frame.plot = FALSE, main="")
+    raster::image(r, col = colour_scale, frame.plot = FALSE, main="", maxpixels=ncell(r))
   }
   dev.off()
 
